(v0.3.0)=
### 0.3.0 {small}`2017-11-16`

- {class}`~anndata.AnnData` gains method {meth}`~anndata.AnnData.concatenate` {smaller}`A Wolf`
- {class}`~anndata.AnnData` is available as the separate [anndata] package {smaller}`P Angerer, A Wolf`
- results of [PAGA](https://github.com/theislab/paga) simplified {smaller}`A Wolf`

[anndata]: https://pypi.org/project/anndata/
